function f = rhs(u,Pe,Da,n);

% function f = rhs(u);
%
% Purpose: compute the right-hand function of the spatially discretized
%          (non-dimensionalized) advection-diffusion-reaction equation for a
%          tubular reactor
%
%            du/dtheta = - du/dz + 1/Pe d^2u/dz^2 - Da u^n
%
%          using backward finite differences for the advection term and central
%          finite differences for the diffusion term
%
% Input: u  ... concentration
%        Pe ... Peclet number
%        Da ... Damkoehler number
%        n  ... order of reaction
%
% Output: f ... right-hand side function, i.e. du/dtheta
%
% Notes: None.
% 

  % get number of grid points
  N = length(u);

  % compute grid spacing \Delta z (since non-dimensionalized 1/(N+1))
  dz = 1./(N + 1);

  % compute boundary values u_{0} and u_{N+1}
  Pedz = Pe*dz;
  u0   = 0.; % ... COMPLETE HERE ...
  uNp1 = 0.; % ... COMPLETE HERE ...

  % set up u array with boundary values, i.e. "ghost points"
  % uGH = [u_{0},u_{1},u_{2}, ... ,u_{N-1},u_{N},u_{N+1}]
  uGH = [u0; u; uNp1];

  % compute right-hand side function f
  f = zeros(size(uGH)); % ... COMPLETE HERE ...

